==> subject-area-api-1.4-sources.jar: org/odpi/openmetadata/accessservices/subjectarea/events/GlossaryArtifactsRelatedEntityType.java <==
/* SPDX-License-Identifier: Apache-2.0 */
package org.odpi.openmetadata.accessservices.subjectarea.events;

import com.fasterxml.jackson.annotation.JsonAutoDetect;
import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import com.fasterxml.jackson.annotation.JsonInclude;

import java.io.Serializable;

import static com.fasterxml.jackson.annotation.JsonAutoDetect.Visibility.NONE;
import static com.fasterxml.jackson.annotation.JsonAutoDetect.Visibility.PUBLIC_ONLY;

/**
 * GlossaryArtifactsRelatedEntityType describes the different types of entity that can change related to Glossaries , Glossary Categories and Glossary Terms.
 */
@JsonAutoDetect(getterVisibility=PUBLIC_ONLY, setterVisibility=PUBLIC_ONLY, fieldVisibility=NONE)
@JsonInclude(JsonInclude.Include.NON_NULL)
@JsonIgnoreProperties(ignoreUnknown=true)
public enum GlossaryArtifactsRelatedEntityType implements Serializable
{
    UNKNOWN         (0,  "Unknown",           "Unknown related entity has changed."),

    COLLECTION      (1,  "Collection",         "Collection changed."),
    TODO            (2,  "Todo",               "Todo changed."),
    MEETING         (3,  "Meeting",            "Meeting changed."),
    INFORMAL_TAG    (4,  "InformalTag",        "Informal Tag changed."),
    COMMENT         (5,  "Comment",            "Comment changed."),
    NOTE            (6,  "Note",               "Note changed."),
    // only applicable to Glossary Node
    ASSET           (7,  "Asset",              "Asset changed.");


    private static final long     serialVersionUID = 1L;

    private  int      eventTypeCode;
    private  String   eventTypeName;
    private  String   eventTypeDescription;


    /**
     * Default Constructor - sets up the specific values for this instance of the enum.
     *
     * @param eventTypeCode - int identifier used for indexing based on the enum.
     * @param eventTypeName - string name used for messages that include the enum.
     * @param eventTypeDescription - default description for the enum value - used when natural resource
     *                                     bundle is not available.
     */
    GlossaryArtifactsRelatedEntityType(int eventTypeCode, String eventTypeName, String eventTypeDescription)
    {
        this.eventTypeCode = eventTypeCode;
        this.eventTypeName = eventTypeName;
        this.eventTypeDescription = eventTypeDescription;
    }


    /**
     * Return the int identifier used for indexing based on the enum.
     *
     * @return int identifier code
     */
    public int getEventTypeCode()
    {
        return eventTypeCode;
    }


    /**
     * Return the string name used for messages that include the enum.
     *
     * @return String name
     */
    public String getEventTypeName()
    {
        return eventTypeName;
    }


    /**
     * Return the default description for the enum value - used when natural resource
     * bundle is not available.
     *
     * @return String default description
     */
    public String getEventTypeDescription()
    {
        return eventTypeDescription;
    }
}

==> subject-area-api-2.9-sources.jar: org/odpi/openmetadata/accessservices/subjectarea/events/GlossaryArtifactsRelatedEntityType.java <==
/* SPDX-License-Identifier: Apache-2.0 */
package org.odpi.openmetadata.accessservices.subjectarea.events;

import com.fasterxml.jackson.annotation.JsonAutoDetect;
import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import com.fasterxml.jackson.annotation.JsonInclude;

import java.io.Serializable;

import static com.fasterxml.jackson.annotation.JsonAutoDetect.Visibility.NONE;
import static com.fasterxml.jackson.annotation.JsonAutoDetect.Visibility.PUBLIC_ONLY;

/**
 * GlossaryArtifactsRelatedEntityType describes the different types of entity that can change related to Glossaries , Glossary Categories and Glossary Terms.
 */
@JsonAutoDetect(getterVisibility=PUBLIC_ONLY, setterVisibility=PUBLIC_ONLY, fieldVisibility=NONE)
@JsonInclude(JsonInclude.Include.NON_NULL)
@JsonIgnoreProperties(ignoreUnknown=true)
public enum GlossaryArtifactsRelatedEntityType implements Serializable
{
    UNKNOWN         (0,  "Unknown",           "Unknown related entity has changed."),

    COLLECTION      (1,  "Collection",         "Collection changed."),
    TODO            (2,  "Todo",               "Todo changed."),
    MEETING         (3,  "Meeting",            "Meeting changed."),
    INFORMAL_TAG    (4,  "InformalTag",        "Informal Tag changed."),
    COMMENT         (5,  "Comment",            "Comment changed."),
    NOTE            (6,  "Note",               "Note changed."),
    // only applicable to Term Node
    ASSET           (7,  "Asset",              "Asset changed.");


    private static final long     serialVersionUID = 1L;

    private  int      eventTypeCode;
    private  String   eventTypeName;
    private  String   eventTypeDescription;


    /**
     * Default Constructor - sets up the specific values for this instance of the enum.
     *
     * @param eventTypeCode - int identifier used for indexing based on the enum.
     * @param eventTypeName - string name used for messages that include the enum.
     * @param eventTypeDescription - default description for the enum value - used when natural resource
     *                                     bundle is not available.
     */
    GlossaryArtifactsRelatedEntityType(int eventTypeCode, String eventTypeName, String eventTypeDescription)
    {
        this.eventTypeCode = eventTypeCode;
        this.eventTypeName = eventTypeName;
        this.eventTypeDescription = eventTypeDescription;
    }


    /**
     * Return the int identifier used for indexing based on the enum.
     *
     * @return int identifier code
     */
    public int getEventTypeCode()
    {
        return eventTypeCode;
    }


    /**
     * Return the string name used for messages that include the enum.
     *
     * @return String name
     */
    public String getEventTypeName()
    {
        return eventTypeName;
    }


    /**
     * Return the default description for the enum value - used when natural resource
     * bundle is not available.
     *
     * @return String default description
     */
    public String getEventTypeDescription()
    {
        return eventTypeDescription;
    }
}
